summaryrefslogtreecommitdiffstats
path: root/libmount/src/monitor.c
diff options
context:
space:
mode:
authorKarel Zak2015-01-13 11:57:15 +0100
committerKarel Zak2015-01-13 11:57:15 +0100
commit0cf8312703d711f7a3e55d47e13266184501672c (patch)
tree5ff718ba4a644a6b5ec1cdea996cf03fe46eba78 /libmount/src/monitor.c
parentlibsmartcols: cleanup gtk-docs warnings (diff)
downloadkernel-qcow2-util-linux-0cf8312703d711f7a3e55d47e13266184501672c.tar.gz
kernel-qcow2-util-linux-0cf8312703d711f7a3e55d47e13266184501672c.tar.xz
kernel-qcow2-util-linux-0cf8312703d711f7a3e55d47e13266184501672c.zip
libmount: cleanup gtk-docs warnings
Signed-off-by: Karel Zak <kzak@redhat.com>
Diffstat (limited to 'libmount/src/monitor.c')
-rw-r--r--libmount/src/monitor.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libmount/src/monitor.c b/libmount/src/monitor.c
index f0d91d931..f7323f693 100644
--- a/libmount/src/monitor.c
+++ b/libmount/src/monitor.c
@@ -573,7 +573,7 @@ int mnt_monitor_close_fd(struct libmnt_monitor *mn)
*
* The file descriptor is associated with all monitored files and it's usable
* for example for epoll. You have to call mnt_monitor_event_cleanup() or
* mnt_monitor_next_changed() after each event.
*
* Returns: >=0 (fd) on success, <0 on error
*/
@@ -673,7 +673,7 @@ static struct monitor_entry *get_changed(struct libmnt_monitor *mn)
}
/**
- * mnt_monitor_next_changed:
+ * mnt_monitor_next_change:
* @mn: monitor
* @filename: returns changed file (optional argument)
* @type: returns MNT_MONITOR_TYPE_* (optional argument)
@@ -682,7 +682,7 @@ static struct monitor_entry *get_changed(struct libmnt_monitor *mn)
*
* Returns: 0 on success, 1 no change, <0 on error
*/
-int mnt_monitor_next_changed(struct libmnt_monitor *mn,
+int mnt_monitor_next_change(struct libmnt_monitor *mn,
const char **filename,
int *type)
{
@@ -846,7 +846,7 @@ int test_epoll(struct libmnt_test *ts, int argc, char *argv[])
continue;
printf(" top-level FD active\n");
- while (mnt_monitor_next_changed(mn, &filename, NULL) == 0)
+ while (mnt_monitor_next_change(mn, &filename, NULL) == 0)
printf(" %s: change detected\n", filename);
} while (1);
@@ -873,7 +873,7 @@ int test_wait(struct libmnt_test *ts, int argc, char *argv[])
while (mnt_monitor_wait(mn, -1) > 0) {
printf("notification detected\n");
- while (mnt_monitor_next_changed(mn, &filename, NULL) == 0)
+ while (mnt_monitor_next_change(mn, &filename, NULL) == 0)
printf(" %s: change detected\n", filename);
}
@@ -573,7 +573,7 @@ int mnt_monitor_close_fd(struct libmnt_monitor *mn)
* The file descriptor is associated with all monitored files and it's usable
* for example for epoll. You have to call mnt_monitor_event_cleanup() or
- * mnt_monitor_next_changed() after each event.
+ * mnt_monitor_next_change() after each event.
*
* Returns: >=0 (fd) on success, <0 on error